/*
 *  kmessagebox_31.cpp  -  kdelibs KMessageBox class for KDE < 3.2 compatibility
 *  Program:  kalarm
 *  Copyright (C) 2004 by David Jarvie <software@astrojar.org.uk>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include <kconfig.h>
#include <kglobal.h>
#include <kmessagebox_31.h>
#undef KMessageBox

#if KDE_VERSION < 290
int KMessageBox_31::warningYesNo(QWidget* parent, const QString& text, const QString& caption,
                                 const QString& buttonYes, const QString& buttonNo,
                                 const QString& dontAskAgainName, bool notify)
{
	ButtonCode result;
	if (!dontAskAgainName.isEmpty()  &&  !shouldBeShownYesNo(dontAskAgainName, result))
		return result;
	return KMessageBox::warningYesNo(parent, text, caption, buttonYes, buttonNo, notify);
}

#if KDE_VERSION < 220
int KMessageBox_31::warningContinueCancel(QWidget* parent, const QString& text, const QString& caption,
                                          const QString& buttonContinue,
                                          const QString& dontAskAgainName, bool notify)
{
	if (!dontAskAgainName.isEmpty()  &&  !shouldBeShownContinue(dontAskAgainName))
		return KMessageBox::Continue;
	return KMessageBox::warningContinueCancel(parent, text, caption, buttonContinue, notify);
}
#endif
#endif

bool KMessageBox_31::shouldBeShownYesNo(const QString& dontShowAgainName, ButtonCode& result)
{
	KConfig* config = KGlobal::config();
	config->setGroup(QString::fromLatin1("Notification Messages"));
	QString dontAsk = config->readEntry(dontShowAgainName).lower();
	if (dontAsk == QString::fromLatin1("yes"))
	{
		result = Yes;
		return false;
	}
	if (dontAsk == QString::fromLatin1("no"))
	{
		result = No;
		return false;
	}
	return true;
}

bool KMessageBox_31::shouldBeShownContinue(const QString& dontShowAgainName)
{
	KConfig* config = KGlobal::config();
	config->setGroup(QString::fromLatin1("Notification Messages"));
	return config->readBoolEntry(dontShowAgainName, true);
}
